@@ -1,13 +1,11 @@
+import os
 import gtk
 
-from .common import get_icon_pixbuf, ICONDIR
-
-import appindicator
+from .common import get_icon_path
 
 def StatusIcon(title):
-    ind = appindicator.Indicator("ginvoke", "ginvoke", appindicator.CATEGORY_APPLICATION_STATUS, ICONDIR)
-    ind.set_status(appindicator.STATUS_ACTIVE)
-    return ind
+    # TODO we can probably do this with get_icon_pixbuf()
+    return gtk.status_icon_new_from_file(get_icon_path())
 
 class PopupMenu(gtk.Menu):
     def __init__(self):
